# LLA-Flow

## Original code

[https://github.com/mansang127/LLA-Flow](https://github.com/mansang127/LLA-Flow)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@inproceedings{Xu2023LLAFlowAL,
  title={LLA-Flow: A Lightweight Local Aggregation on Cost Volume for Optical Flow Estimation},
  author={Jiawei Xu and Zongqing Lu and Qingmin Liao},
  booktitle={IEEE International Conference on Image Processing (ICIP)},
  year={2023},
  pages={3220-3224},
  url={https://api.semanticscholar.org/CorpusID:258179047}
}
```